@@ -1,5 +1,7 @@
 `image.mefa` <-
-function(x, segm=NULL, trafo=c("none", "log", "bins", "prab"), probs = seq(0, 1, 0.05), ordering=TRUE, reverse=TRUE, ylab=NULL, xlab=NULL, show=TRUE, ...)
+function(x, segm=NULL, trafo=c("none", "log", "bins", "prab"), 
+probs = seq(0, 1, 0.05), ordering=TRUE, reverse=TRUE, 
+ylab=NULL, xlab=NULL, show=TRUE, ...)
 {
 if (!is.mefa(x))
     stop("object is not of class 'mefa'")
@@ -7,11 +9,11 @@ if (length(trafo) > 1) trafo <- trafo[1]
 trafo <- match.arg(trafo, c("none", "log", "bins", "prab"))
 m <- if (!is.null(segm))
     x$segm[[segm]] else x$xtab
+# ordering based on totals
 if (ordering)
     m <- m[order(rowSums(x$xtab)), order(colSums(x$xtab),decreasing=TRUE)]
-
 mm <- t(m)
-
+# transformations
 if (trafo == "log")
     mm <- log10(mm)
 if (trafo == "bins")
